==> bce-java-sdk-0.10.292-sources.jar: com/baidubce/services/bec/model/blb/GetBecBlbResourceMetricsRequest.java <==
/*
 * Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bec.model.blb;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import lombok.Data;

/**
 * The request for getting the BEC blb monitor metrics.
 */
@Data
public class GetBecBlbResourceMetricsRequest extends AbstractBceRequest {

    /**
     * The id of the blb.
     */
    private String blbId;

    /**
     * The type of the metrics.
     */
    private String type;

    /**
     * The type of the network.
     */
    private String ipType;

    /**
     * Offset in seconds.
     */
    private Integer offsetInSeconds;

    /**
     * Query port.
     */
    private String port;

    /**
     * ServiceProvider.
     */
    private String serviceProvider;

    /**
     * stepInMin
     */
    private Integer stepInMin;

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return GetInstanceRequest with credentials.
     */
    public GetBecBlbResourceMetricsRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}

==> bce-java-sdk-0.10.358-sources.jar: com/baidubce/services/bec/model/blb/GetBecBlbResourceMetricsRequest.java <==
/*
 * Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bec.model.blb;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import lombok.Data;

/**
 * The request for getting the BEC blb monitor metrics.
 */
@Data
public class GetBecBlbResourceMetricsRequest extends AbstractBceRequest {

    /**
     * The id of the blb.
     */
    private String blbId;

    /**
     * The metrics type.
     */
    private String metricsType;

    /**
     * The type of the network.
     */
    private String ipType;

    /**
     * Query port.
     */
    private String port;

    /**
     * The start time, unix timestamp, the unit is second.
     */
    private Long start;

    /**
     * The start time, unix timestamp, the unit is second.
     */
    private Long end;

    /**
     * ServiceProvider.
     */
    private String serviceProvider;

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return GetInstanceRequest with credentials.
     */
    public GetBecBlbResourceMetricsRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}
